@@ -37,7 +37,7 @@
 
 monitoring_plugin *this_monitoring_plugin=NULL;
 
-unsigned int timeout_state = STATE_CRITICAL;
+int timeout_state = STATE_CRITICAL;
 unsigned int timeout_interval = DEFAULT_SOCKET_TIMEOUT;
 
 bool _np_state_read_file(FILE *);
