@@ -5,7 +5,7 @@
 
 FILE *spopen (const char *);
 int spclose (FILE *);
-RETSIGTYPE popen_timeout_alarm_handler (int);
+void popen_timeout_alarm_handler (int);
 
 pid_t *childpid=NULL;
 int *child_stderr_array=NULL;
